@@ -1,7 +1,5 @@
 from configparser import ConfigParser
-from pkg_resources import Requirement, resource_filename
 
-global prefs
 prefs = None
 
 defaults = {
@@ -10,7 +8,10 @@ defaults = {
             'cache': r'''C:\Windows\Temp\ppt-cache''',
             'cache_format': 'JPG',
             'cache_timeout': 5*60,
-            'blackwhite': 'both'
+            'cache_init': True,
+            'blackwhite': 'both',
+            'refresh': 2,
+            'disable_protected': True
         },
         'HTTP': {
             'interface': '',
@@ -41,3 +42,11 @@ def loadconf(configpaths):
         print("Error processing config: " + str(e))
     return prefs
 
+def export_defaults(file):
+    """
+    Write the default settings to a file object, including comments and with spaces around 
+    delimeters. This function is intended to be used to populate the config file with defaults
+    after installation.
+    """
+    prefs = loadconf([])
+    prefs.write(file, space_around_delimiters=True)
